<?php

namespace Litepie\Slider\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Slider\Forms\Slider as SliderForm;
use Litepie\Slider\Http\Requests\SliderResourceRequest;
use Litepie\Slider\Http\Resources\SliderResource;
use Litepie\Slider\Http\Resources\SlidersCollection;
use Litepie\Slider\Models\Slider;
use Litepie\Slider\Actions\SliderAction;
use Litepie\Slider\Actions\SliderActions;


/**
 * Resource controller class for slider.
 */
class SliderResourceController extends BaseController
{

    /**
     * Initialize slider resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = SliderForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('litepie.slider.modules'), 'slider', guard_url('slider'));
    }

    /**
     * Display a list of slider.
     *
     * @return Response
     */
    public function index(SliderResourceRequest $request)
    {
        $request = $request->all();
        $page = SliderActions::run('paginate', $request);

        $data = new SlidersCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('slider::slider.names'))
            ->view('slider::slider.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function show(SliderResourceRequest $request, Slider $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SliderResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('slider::slider.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('slider::slider.show')
            ->output();
    }

    /**
     * Show the form for creating a new slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SliderResourceRequest $request, Slider $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SliderResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('slider::slider.name'))
            ->view('slider::slider.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SliderResourceRequest $request, Slider $model)
    {
        try {
            $request = $request->all();
            $model = SliderAction::run('store', $model, $request);
            $data = new SliderResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('slider::slider.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('slider/slider/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/slider/slider'))
                ->redirect();
        }

    }

    /**
     * Show slider for editing.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function edit(SliderResourceRequest $request, Slider $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new SliderResource($model);
        // return view('slider::slider.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('slider::slider.name'))
            ->view('slider::slider.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function update(SliderResourceRequest $request, Slider $model)
    {
        try {
            $request = $request->all();
            $model = SliderAction::run('update', $model, $request);
            $data = new SliderResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('slider::slider.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('slider/slider/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/slider/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the slider.
     *
     * @param Model   $slider
     *
     * @return Response
     */
    public function destroy(SliderResourceRequest $request, Slider $model)
    {
        try {

            $request = $request->all();
            $model = SliderAction::run('destroy', $model, $request);
            $data = new SliderResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('slider::slider.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('slider/slider/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/slider/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
